@@ -4,7 +4,7 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000012';
+our $VERSION = '0.000013';
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
@@ -359,7 +359,7 @@ sub wait {
 
     $hub->cull;
 
-    cluck "All children have completed, but we still appear to be pending"
+    cluck "Subtest '$self->{+NAME}': All children have completed, but we still appear to be pending"
         if $hub->is_local && keys %{$self->{+HUB}->ast_ids};
 }
 
